You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tapestry.apache.org by hl...@apache.org on 2008/10/14 00:31:48 UTC

svn commit: r704275 - in /tapestry/tapestry5/trunk: tapestry-core/src/main/java/org/apache/tapestry5/ tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/ tapestry-core/src/main/java/org/apache/tapestry5/internal/services/ tapestry-core...

Author: hlship
Date: Mon Oct 13 15:31:47 2008
New Revision: 704275

URL: http://svn.apache.org/viewvc?rev=704275&view=rev
Log:
TAP5-136: Although hibernate dependencies are not longer provided the documentation still says they are

Modified:
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/EventConstants.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/BeanEditForm.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Form.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Submit.java
    tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/internal/services/FieldValidationSupportImpl.java
    tapestry/tapestry5/trunk/tapestry-core/src/test/java/org/apache/tapestry5/corelib/components/SubmitTest.java
    tapestry/tapestry5/trunk/tapestry-core/src/test/java/org/apache/tapestry5/internal/services/FieldValidationSupportImplTest.java
    tapestry/tapestry5/trunk/tapestry-hibernate/pom.xml
    tapestry/tapestry5/trunk/tapestry-hibernate/src/site/apt/conf.apt
    tapestry/tapestry5/trunk/tapestry-hibernate/src/site/apt/index.apt

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/EventConstants.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/EventConstants.java?rev=704275&r1=704274&r2=704275&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/EventConstants.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/EventConstants.java Mon Oct 13 15:31:47 2008
@@ -9,15 +9,91 @@
      * Default client event name, "action", used in most situations.
      */
     public static final String ACTION = "action";
+
     /**
      * Event triggered when a page is activated (for rendering). The component event handler will be passed the context
      * provided by the passivate event.
      */
     public static final String ACTIVATE = "activate";
+
     /**
      * Event triggered when a link for a page is generated. The event handler for the page may provide an object, or an
      * array of objects, as the context for the page. These values will become part of the page's context, and will be
      * provided back when the page is activated.
      */
     public static final String PASSIVATE = "passivate";
+
+    /**
+     * Invoked before {@link #PREPARE} when rendering out the form.
+     *
+     * @see org.apache.tapestry5.corelib.components.Form
+     */
+    public static final String PREPARE_FOR_RENDER = "prepareForRender";
+
+    /**
+     * Invoked before {@link #PREPARE} when the form is submitted.
+     *
+     * @see org.apache.tapestry5.corelib.components.Form
+     */
+    public static final String PREPARE_FOR_SUBMIT = "prepareForSubmit";
+
+    /**
+     * Invoked to let the containing component(s) prepare for the form rendering or the form submission.
+     *
+     * @see org.apache.tapestry5.corelib.components.Form
+     */
+    public static final String PREPARE = "prepare";
+
+    /**
+     * Event type for a notification after the form has submitted. This event notification occurs on any form submit,
+     * without respect to "success" or "failure".
+     *
+     * @see org.apache.tapestry5.corelib.components.Form
+     */
+    public static final String SUBMIT = "submit";
+
+    /**
+     * Event type for a notification to perform validation of submitted data. This allows a listener to perform
+     * cross-field validation. This occurs before the {@link #SUCCESS} or {@link #FAILURE} notification.
+     *
+     * @see org.apache.tapestry5.corelib.components.Form
+     */
+    public static final String VALIDATE_FORM = "validateForm";
+
+    /**
+     * Event type for a notification after the form has submitted, when there are no errors in the validation tracker.
+     * This occurs before the {@link #SUBMIT} event.
+     *
+     * @see org.apache.tapestry5.corelib.components.Form
+     */
+    public static final String SUCCESS = "success";
+
+    /**
+     * Event type for a notification after the form has been submitted, when there are errors in the validation tracker.
+     * This occurs before the {@link #SUBMIT} event.
+     */
+    public static final String FAILURE = "failure";
+
+    /**
+     * Event type triggered by the {@link org.apache.tapestry5.corelib.components.Submit} component when it is the cause
+     * of the form submission.
+     */
+    public static final String SELECTED = "selected";
+
+    /**
+     * Event triggered by some form-related cmponents to parse a value provided by the client. This takes the place of a
+     * {@link org.apache.tapestry5.Translator}.
+     */
+    public static final String PARSE_CLIENT = "parseClient";
+
+    /**
+     * Event triggered by some form-related components to convert a server-side value to a client-side string, as an
+     * alternative to a {@link org.apache.tapestry5.Translator}.
+     */
+    public static final String TO_CLIENT = "toClient";
+
+    /**
+     * Event triggered by form-related components to validate user input.
+     */
+    public static final String VALIDATE = "validate";
 }

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/BeanEditForm.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/BeanEditForm.java?rev=704275&r1=704274&r2=704275&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/BeanEditForm.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/BeanEditForm.java Mon Oct 13 15:31:47 2008
@@ -128,7 +128,7 @@
 
     void onPrepareFromForm()
     {
-        resources.triggerEvent(Form.PREPARE, null, null);
+        resources.triggerEvent(EventConstants.PREPARE, null, null);
 
         if (model == null)
         {

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Form.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Form.java?rev=704275&r1=704274&r2=704275&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Submit.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Submit.java Mon Oct 13 15:31:47 2008
@@ -17,6 +17,7 @@
 import org.apache.tapestry5.BindingConstants;
 import org.apache.tapestry5.ComponentResources;
 import org.apache.tapestry5.MarkupWriter;
+import org.apache.tapestry5.EventConstants;
 import org.apache.tapestry5.annotations.Environmental;
 import org.apache.tapestry5.annotations.Mixin;
 import org.apache.tapestry5.annotations.Parameter;
@@ -34,7 +35,6 @@
  */
 public class Submit extends AbstractField
 {
-    static final String SELECTED_EVENT = "selected";
 
     /**
      * If true (the default), then any notification sent by the component will be deferred until the end of the form
@@ -48,7 +48,7 @@
      * is "selected".
      */
     @Parameter(allowNull = false, defaultPrefix = BindingConstants.LITERAL)
-    private String event = SELECTED_EVENT;
+    private String event = EventConstants.SELECTED;
 
     @Environmental
     private FormSupport formSupport;

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/internal/services/FieldValidationSupportImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/internal/services/FieldValidationSupportImpl.java?rev=704275&r1=704274&r2=704275&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/internal/services/FieldValidationSupportImpl.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/internal/services/FieldValidationSupportImpl.java Mon Oct 13 15:31:47 2008
@@ -24,10 +24,6 @@
 
 public class FieldValidationSupportImpl implements FieldValidationSupport
 {
-    static final String PARSE_CLIENT_EVENT = "parseClient";
-    static final String TO_CLIENT_EVENT = "toClient";
-    static final String VALIDATE_EVENT = "validate";
-
     private final TypeCoercer typeCoercer;
 
     public FieldValidationSupportImpl(TypeCoercer typeCoercer)
@@ -61,7 +57,7 @@
             }
         };
 
-        componentResources.triggerEvent(TO_CLIENT_EVENT, new Object[] {value}, callback);
+        componentResources.triggerEvent(EventConstants.TO_CLIENT, new Object[] {value}, callback);
 
         if (resultHolder.hasValue()) return resultHolder.get();
 
@@ -115,7 +111,7 @@
 
         try
         {
-            componentResources.triggerEvent(PARSE_CLIENT_EVENT, new Object[] {effectiveValue}, callback);
+            componentResources.triggerEvent(EventConstants.PARSE_CLIENT, new Object[] {effectiveValue}, callback);
         }
         catch (RuntimeException ex)
         {
@@ -154,7 +150,7 @@
 
         try
         {
-            componentResources.triggerEvent(VALIDATE_EVENT, new Object[] {value}, null);
+            componentResources.triggerEvent(EventConstants.VALIDATE, new Object[] {value}, null);
         }
         catch (RuntimeException ex)
         {

Modified: tapestry/tapestry5/trunk/tapestry-core/src/test/java/org/apache/tapestry5/corelib/components/SubmitTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/test/java/org/apache/tapestry5/corelib/components/SubmitTest.java?rev=704275&r1=704274&r2=704275&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/test/java/org/apache/tapestry5/corelib/components/SubmitTest.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/test/java/org/apache/tapestry5/corelib/components/SubmitTest.java Mon Oct 13 15:31:47 2008
@@ -15,6 +15,7 @@
 package org.apache.tapestry5.corelib.components;
 
 import org.apache.tapestry5.ComponentResources;
+import org.apache.tapestry5.EventConstants;
 import org.apache.tapestry5.corelib.internal.FormSupportImpl;
 import org.apache.tapestry5.internal.services.HeartbeatImpl;
 import org.apache.tapestry5.internal.test.InternalBaseTestCase;
@@ -64,7 +65,7 @@
 
         verify();
 
-        expect(resources.triggerEvent(Submit.SELECTED_EVENT, null, null)).andReturn(false);
+        expect(resources.triggerEvent(EventConstants.SELECTED, null, null)).andReturn(false);
 
         replay();
 
@@ -98,7 +99,7 @@
 
         verify();
 
-        expect(resources.triggerEvent(Submit.SELECTED_EVENT, null, null)).andReturn(false);
+        expect(resources.triggerEvent(EventConstants.SELECTED, null, null)).andReturn(false);
 
         replay();
 

Modified: tapestry/tapestry5/trunk/tapestry-core/src/test/java/org/apache/tapestry5/internal/services/FieldValidationSupportImplTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/test/java/org/apache/tapestry5/internal/services/FieldValidationSupportImplTest.java?rev=704275&r1=704274&r2=704275&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-core/src/test/java/org/apache/tapestry5/internal/services/FieldValidationSupportImplTest.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/test/java/org/apache/tapestry5/internal/services/FieldValidationSupportImplTest.java Mon Oct 13 15:31:47 2008
@@ -61,7 +61,7 @@
             }
         };
 
-        EasyMock.expect(resources.triggerEvent(EasyMock.eq(FieldValidationSupportImpl.PARSE_CLIENT_EVENT),
+        EasyMock.expect(resources.triggerEvent(EasyMock.eq(EventConstants.PARSE_CLIENT),
                                                EasyMock.isA(Object[].class),
                                                EasyMock.isA(ComponentEventCallback.class))).andAnswer(answer);
 
@@ -89,7 +89,7 @@
 
         train_replaceFromClient(nullFieldStrategy, "");
 
-        ignoreEvent(resources, FieldValidationSupportImpl.PARSE_CLIENT_EVENT, clientValue);
+        ignoreEvent(resources, EventConstants.PARSE_CLIENT, clientValue);
 
         expect(translator.parse(clientValue)).andReturn("");
 
@@ -127,7 +127,7 @@
 
         String clientValue = "abracadabra";
 
-        EasyMock.expect(resources.triggerEvent(EasyMock.eq(FieldValidationSupportImpl.PARSE_CLIENT_EVENT),
+        EasyMock.expect(resources.triggerEvent(EasyMock.eq(EventConstants.PARSE_CLIENT),
                                                EasyMock.isA(Object[].class),
                                                EasyMock.isA(ComponentEventCallback.class))).andThrow(
                 new RuntimeException(ve));
@@ -164,7 +164,7 @@
         String clientValue = "abracadabra";
 
 
-        EasyMock.expect(resources.triggerEvent(EasyMock.eq(FieldValidationSupportImpl.PARSE_CLIENT_EVENT),
+        EasyMock.expect(resources.triggerEvent(EasyMock.eq(EventConstants.PARSE_CLIENT),
                                                EasyMock.isA(Object[].class),
                                                EasyMock.isA(ComponentEventCallback.class))).andThrow(re);
 
@@ -198,7 +198,7 @@
 
         String clientValue = "abracadabra";
 
-        ignoreEvent(resources, FieldValidationSupportImpl.PARSE_CLIENT_EVENT, clientValue);
+        ignoreEvent(resources, EventConstants.PARSE_CLIENT, clientValue);
 
         expect(translator.parse(clientValue)).andReturn("foobar");
 
@@ -226,7 +226,7 @@
 
         String clientValue = "abracadabra";
 
-        EasyMock.expect(resources.triggerEvent(EasyMock.eq(FieldValidationSupportImpl.TO_CLIENT_EVENT),
+        EasyMock.expect(resources.triggerEvent(EasyMock.eq(EventConstants.TO_CLIENT),
                                                EasyMock.aryEq(new Object[] {value}),
                                                EasyMock.isA(ComponentEventCallback.class))).andReturn(false);
 
@@ -266,7 +266,7 @@
             }
         };
 
-        EasyMock.expect(resources.triggerEvent(EasyMock.eq(FieldValidationSupportImpl.TO_CLIENT_EVENT),
+        EasyMock.expect(resources.triggerEvent(EasyMock.eq(EventConstants.TO_CLIENT),
                                                EasyMock.aryEq(new Object[] {value}),
                                                EasyMock.isA(ComponentEventCallback.class))).andAnswer(answer);
 
@@ -303,7 +303,7 @@
             }
         };
 
-        EasyMock.expect(resources.triggerEvent(EasyMock.eq(FieldValidationSupportImpl.TO_CLIENT_EVENT),
+        EasyMock.expect(resources.triggerEvent(EasyMock.eq(EventConstants.TO_CLIENT),
                                                EasyMock.aryEq(new Object[] {value}),
                                                EasyMock.isA(ComponentEventCallback.class))).andAnswer(answer);
 
@@ -342,7 +342,7 @@
 
         ComponentEventCallback handler = null;
 
-        expect(resources.triggerEvent(EasyMock.eq(FieldValidationSupportImpl.VALIDATE_EVENT),
+        expect(resources.triggerEvent(EasyMock.eq(EventConstants.VALIDATE),
                                       EasyMock.aryEq(new Object[] {value}), EasyMock.eq(handler))).andReturn(true);
 
 
@@ -371,7 +371,7 @@
 
         fv.validate(value);
 
-        expect(resources.triggerEvent(eq(FieldValidationSupportImpl.VALIDATE_EVENT),
+        expect(resources.triggerEvent(eq(EventConstants.VALIDATE),
                                       EasyMock.aryEq(new Object[] {value}), eq(handler))).andThrow(re);
 
 

Modified: tapestry/tapestry5/trunk/tapestry-hibernate/pom.xml
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-hibernate/pom.xml?rev=704275&r1=704274&r2=704275&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-hibernate/pom.xml (original)
+++ tapestry/tapestry5/trunk/tapestry-hibernate/pom.xml Mon Oct 13 15:31:47 2008
@@ -50,11 +50,8 @@
             <scope>test</scope>
         </dependency>
 
-        <!-- The Hibernate dependencies are provided; which gives the final application
-the ability to choose the appropriate version.  Further, in many cases
-(such as JBoss deployment), they are, in fact, provided by the
-container.  For a Tomcat deployment, you're more likely to include
-the hibernate JARs and dependencies inside the WAR. -->
+        <!-- This is the default version of Hibernate used; Maven provides the ability to override this dependency, though
+         it can be tricky because there are overlapping third-party dependencies with slightly different version numbers. -->
         <dependency>
             <groupId>org.hibernate</groupId>
             <artifactId>hibernate-core</artifactId>

Modified: tapestry/tapestry5/trunk/tapestry-hibernate/src/site/apt/conf.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-hibernate/src/site/apt/conf.apt?rev=704275&r1=704274&r2=704275&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-hibernate/src/site/apt/conf.apt (original)
+++ tapestry/tapestry5/trunk/tapestry-hibernate/src/site/apt/conf.apt Mon Oct 13 15:31:47 2008
@@ -6,7 +6,9 @@
 
   The Tapestry Hibernate Library is responsible for configuring Hibernate for you. This is done in a just-in-time manner, the first time
   a Hibernate Session is required.
-  
+
+* HibernateSessionSource Configuration
+
   One way to configure hibernate is to create a <<<hibernate.cfg.xml>>> file and place it in the root of your application (i.e., under src/main/resources).  Most Hibernate-specific
   configuration occurs in this file. Another way is to contribute objects that perform configuration (such as setting event listeners). Example:
   
@@ -22,8 +24,12 @@
    * <<Default>> - performs default hibernate configuration
    
    * <<PackageName>> - loads entities by package name as contributed to the HibernateEntityPackageManager service
-  
-  For each package contributed the library will:
+
+* HibernateEntityPackageManager Configuration
+
+  This configuration is a set of package names, identifying where to search for entity classes.  
+
+  For each package contributed, the library will:
   
   * {{{http://www.hibernate.org/hib_docs/annotations/api/org/hibernate/cfg/AnnotationConfiguration.html#addPackage(java.lang.String)}Add the package to the configuration}},
     which will load annotations from the package-info class within the named package, if present.

Modified: tapestry/tapestry5/trunk/tapestry-hibernate/src/site/apt/index.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-hibernate/src/site/apt/index.apt?rev=704275&r1=704274&r2=704275&view=diff
==============================================================================
--- tapestry/tapestry5/trunk/tapestry-hibernate/src/site/apt/index.apt (original)
+++ tapestry/tapestry5/trunk/tapestry-hibernate/src/site/apt/index.apt Mon Oct 13 15:31:47 2008
@@ -19,11 +19,9 @@
   License used by the rest of Tapestry. The restrictions mostly apply to redistricuting Hibernate, especially in
   any altered form, and will likely be irrelvant to the vast majority of users, but you should be aware.
   
-  This library is compiled against version <<3.2.2.ga>> of Hibernate (and version 3.2.1.ga of hibernate-annotations),
+  This library is compiled against version <<3.3.1.GA>> of Hibernate (and version 3.4.0.GA of hibernate-annotations),
   but should work with more recent versions.
   
-  You will have to manually setup a dependency against your preferred version of Hibernate in your project's Maven POM,
-  to override the default dependencies provided by tapestry-hibernate.
 
 What's New?
--- tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Form.java (original)
+++ tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Form.java Mon Oct 13 15:31:47 2008
@@ -45,14 +45,16 @@
 /**
  * An HTML form, which will enclose other components to render out the various types of fields.
  * <p/>
- * A Form emits many notification events. When it renders, it fires a {@link #PREPARE_FOR_RENDER} notification, followed
- * by a {@link #PREPARE} notification.
+ * A Form emits many notification events. When it renders, it fires a {@link org.apache.tapestry5.EventConstants#PREPARE_FOR_RENDER}
+ * notification, followed by a {@link org.apache.tapestry5.EventConstants#PREPARE} notification.
  * <p/>
  * When the form is submitted, the component emits several notifications: first a {@link #PREPARE_FOR_SUBMIT}, then a
  * {@link #PREPARE}: these allow the page to update its state as necessary to prepare for the form submission, then
  * (after components enclosed by the form have operated), a {@link #VALIDATE_FORM}event is emitted, to allow for
  * cross-form validation. After that, either a {@link #SUCCESS} OR {@link #FAILURE} event (depending on whether the
  * {@link ValidationTracker} has recorded any errors). Lastly, a {@link #SUBMIT} event, for any listeners that care only
  * about form submission, regardless of success or failure.
  * <p/>
  * For all of these notifications, the event context is derived from the <strong>context</strong> parameter. This
@@ -62,43 +64,39 @@
 public class Form implements ClientElement, FormValidationControl
 {
     /**
-     * Invoked before {@link #PREPARE} when rendering out the form.
+     * @deprecated Use constant from {@link org.apache.tapestry5.EventConstants} instead.
      */
-    public static final String PREPARE_FOR_RENDER = "prepareForRender";
+    public static final String PREPARE_FOR_RENDER = EventConstants.PREPARE_FOR_RENDER;
 
     /**
-     * Invoked before {@link #PREPARE} when the form is submitted.
+     * @deprecated Use constant from {@link org.apache.tapestry5.EventConstants} instead.
      */
-    public static final String PREPARE_FOR_SUBMIT = "prepareForSubmit";
+    public static final String PREPARE_FOR_SUBMIT = EventConstants.PREPARE_FOR_SUBMIT;
 
     /**
-     * Invoked to let the containing component(s) prepare for the form rendering or the form submission.
+     * @deprecated Use constant from {@link org.apache.tapestry5.EventConstants} instead.
      */
-    public static final String PREPARE = "prepare";
+    public static final String PREPARE = EventConstants.PREPARE;
 
     /**
-     * Event type for a notification after the form has submitted. This event notification occurs on any form submit,
-     * without respect to "success" or "failure".
+     * @deprecated Use constant from {@link org.apache.tapestry5.EventConstants} instead.
      */
-    public static final String SUBMIT = "submit";
+    public static final String SUBMIT = EventConstants.SUBMIT;
 
     /**
-     * Event type for a notification to perform validation of submitted data. This allows a listener to perform
-     * cross-field validation. This occurs before the {@link #SUCCESS} or {@link #FAILURE} notification.
+     * @deprecated Use constant from {@link org.apache.tapestry5.EventConstants} instead.
      */
-    public static final String VALIDATE_FORM = "validateForm";
+    public static final String VALIDATE_FORM = EventConstants.VALIDATE_FORM;
 
     /**
-     * Event type for a notification after the form has submitted, when there are no errors in the validation tracker.
-     * This occurs before the {@link #SUBMIT} event.
+     * @deprecated Use constant from {@link org.apache.tapestry5.EventConstants} instead.
      */
-    public static final String SUCCESS = "success";
+    public static final String SUCCESS = EventConstants.SUCCESS;
 
     /**
-     * Event type for a notification after the form has been submitted, when there are errors in the validation tracker.
-     * This occurs before the {@link #SUBMIT} event.
+     * @deprecated Use constant from {@link org.apache.tapestry5.EventConstants} instead.
      */
-    public static final String FAILURE = "failure";
+    public static final String FAILURE = EventConstants.FAILURE;
 
     /**
      * Query parameter name storing form data (the serialized commands needed to process a form submission).
@@ -245,9 +243,9 @@
 
         Object[] contextArray = context == null ? new Object[0] : context.toArray();
 
-        resources.triggerEvent(PREPARE_FOR_RENDER, contextArray, null);
+        resources.triggerEvent(EventConstants.PREPARE_FOR_RENDER, contextArray, null);
 
-        resources.triggerEvent(PREPARE, contextArray, null);
+        resources.triggerEvent(EventConstants.PREPARE, contextArray, null);
 
         Link link = resources.createFormEventLink(EventConstants.ACTION, contextArray);
 
@@ -335,11 +333,11 @@
             ComponentResultProcessorWrapper callback = new ComponentResultProcessorWrapper(
                     componentEventResultProcessor);
 
-            resources.triggerContextEvent(PREPARE_FOR_SUBMIT, context, callback);
+            resources.triggerContextEvent(EventConstants.PREPARE_FOR_SUBMIT, context, callback);
 
             if (callback.isAborted()) return true;
 
-            resources.triggerContextEvent(PREPARE, context, callback);
+            resources.triggerContextEvent(EventConstants.PREPARE, context, callback);
 
             if (callback.isAborted()) return true;
 
@@ -371,13 +369,14 @@
 
             if (!this.tracker.getHasErrors()) this.tracker.clear();
 
-            resources.triggerContextEvent(tracker.getHasErrors() ? FAILURE : SUCCESS, context, callback);
+            resources.triggerContextEvent(tracker.getHasErrors() ? EventConstants.FAILURE : EventConstants.SUCCESS,
+                                          context, callback);
 
             // Lastly, tell anyone whose interested that the form is completely submitted.
 
             if (callback.isAborted()) return true;
 
-            resources.triggerContextEvent(SUBMIT, context, callback);
+            resources.triggerContextEvent(EventConstants.SUBMIT, context, callback);
 
             return callback.isAborted();
         }
@@ -392,7 +391,7 @@
     {
         try
         {
-            resources.triggerContextEvent(VALIDATE_FORM, context, callback);
+            resources.triggerContextEvent(EventConstants.VALIDATE_FORM, context, callback);
         }
         catch (RuntimeException ex)
         {
@@ -45,14 +45,16 @@
  * <p/>
- * When the form is submitted, the component emits several notifications: first a {@link #PREPARE_FOR_SUBMIT}, then a
- * {@link #PREPARE}: these allow the page to update its state as necessary to prepare for the form submission, then
- * (after components enclosed by the form have operated), a {@link #VALIDATE_FORM}event is emitted, to allow for
- * cross-form validation. After that, either a {@link #SUCCESS} OR {@link #FAILURE} event (depending on whether the
- * {@link ValidationTracker} has recorded any errors). Lastly, a {@link #SUBMIT} event, for any listeners that care only
+ * When the form is submitted, the component emits several notifications: first a {@link
+ * org.apache.tapestry5.EventConstants#PREPARE_FOR_SUBMIT}, then a {@link org.apache.tapestry5.EventConstants#PREPARE}:
+ * these allow the page to update its state as necessary to prepare for the form submission, then (after components
+ * enclosed by the form have operated), a {@link org.apache.tapestry5.EventConstants#VALIDATE_FORM}event is emitted, to
+ * allow for cross-form validation. After that, either a {@link org.apache.tapestry5.EventConstants#SUCCESS} OR {@link
+ * org.apache.tapestry5.EventConstants#FAILURE} event (depending on whether the {@link ValidationTracker} has recorded
+ * any errors). Lastly, a {@link org.apache.tapestry5.EventConstants#SUBMIT} event, for any listeners that care only
  * about form submission, regardless of success or failure.
  * <p/>

Modified: tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Submit.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/trunk/tapestry-core/src/main/java/org/apache/tapestry5/corelib/components/Submit.java?rev=704275&r1=704274&r2=704275&view=diff
==============================================================================